@@ -1,11 +1,23 @@
 ###############################################################################
-## OCSINVENTORY-NG 
-## Copyleft Pascal DANEK 2008
-## Web : http://www.ocsinventory-ng.org
+## Copyright 2005-2016 OCSInventory-NG/OCSInventory-Server contributors.
+## See the Contributors file for more details about them.
+## 
+## This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 ##
-## This code is open source and may be copied and modified as long as the source
-## code is always made freely available.
-## Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
+## OCSInventory-NG/OCSInventory-Server is free software: you can redistribute
+## it and/or modify it under the terms of the GNU General Public License as
+## published by the Free Software Foundation, either version 2 of the License,
+## or (at your option) any later version.
+##
+## OCSInventory-NG/OCSInventory-Server is distributed in the hope that it
+## will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+## of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
+## Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+## MA 02110-1301, USA.
 ################################################################################
 package Apache::Ocsinventory::Interface::Database;
 
@@ -21,7 +33,8 @@ our @EXPORT = qw /
   get_dbh_write
   get_dbh_read
   do_sql
-  get_table_pk
+  get_hardware_table_pk
+  get_snmp_table_pk
   get_type_name
   untaint_dbstring
   untaint_dbstring_lst
@@ -89,11 +102,16 @@ sub do_sql {
 }
 
 # Return the id field of an inventory section
-sub get_table_pk{
+sub get_hardware_table_pk{
   my $section = shift;
   return ($section eq 'hardware')?'ID':'HARDWARE_ID';
 }
 
+sub get_snmp_table_pk{
+  my $section = shift;
+  return ($section eq 'snmp')?'ID':'SNMP_ID';
+}
+
 sub get_type_name{
   my ($section, $field, $value) = @_ ;
 
