@@ -1,11 +1,23 @@
 ###############################################################################
-## OCSINVENTORY-NG 
-## Copyleft Pascal DANEK 2006
-## Web : http://www.ocsinventory-ng.org
+## Copyright 2005-2016 OCSInventory-NG/OCSInventory-Server contributors.
+## See the Contributors file for more details about them.
+## 
+## This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 ##
-## This code is open source and may be copied and modified as long as the source
-## code is always made freely available.
-## Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
+## OCSInventory-NG/OCSInventory-Server is free software: you can redistribute
+## it and/or modify it under the terms of the GNU General Public License as
+## published by the Free Software Foundation, either version 2 of the License,
+## or (at your option) any later version.
+##
+## OCSInventory-NG/OCSInventory-Server is distributed in the hope that it
+## will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+## of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
+## Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+## MA 02110-1301, USA.
 ################################################################################
 package Apache::Ocsinventory::Map;
 
@@ -58,7 +70,8 @@ our %DATA_MAP= (
        FIDELITY => {},
        SSTATE => { noXml => 1 },
        USERAGENT => { noXml => 1 },
-       IPSRC => {}
+       IPSRC => {},
+       ARCH => {}
      },
   },
   
@@ -288,6 +301,7 @@ our %DATA_MAP= (
        TYPE => {},
        TYPEMIB => {},
        SPEED => {},
+       MTU => {},
        MACADDR => { fallback => '00:00:00:00:00:00' },
        STATUS => {},
        IPGATEWAY => {},
@@ -308,7 +322,13 @@ our %DATA_MAP= (
        NAME => {},
        DRIVER => {},
        PORT => {},
-       DESCRIPTION => {}
+       DESCRIPTION => {},
+       SERVERNAME => {},
+       SHARENAME => {},
+       RESOLUTION => {},
+       COMMENT => {},
+       SHARED => {},
+       NETWORK => {}
    }
   },
 
@@ -344,14 +364,14 @@ our %DATA_MAP= (
   },
   
   softwares => {
-   mask => 65536,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => 'NAME',
-   writeDiff => 1,
-   cache => 1,
-   fields =>  {
+    mask => 65536,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'NAME',
+    writeDiff => 1,
+    cache => 1,
+    fields =>  {
        PUBLISHER => {},
        NAME => { cache => 1 },
        VERSION => {},
@@ -363,8 +383,8 @@ our %DATA_MAP= (
        GUID => {},
        LANGUAGE => {},
        INSTALLDATE => {},
-       BITSWIDTH => {},
-   }
+       BITSWIDTH => {}
+    }
   },
   
   virtualmachines => {
@@ -382,11 +402,93 @@ our %DATA_MAP= (
       STATUS => {},
       SUBSYSTEM => {},
       VMTYPE => {},
-      VCPU => {},
+      VCPU => {}
     }
   },
 
-javainfo => {
+  cpus => {
+    mask => 262144,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'SERIALNUMBER',
+    writeDiff => 1,
+    cache => 0,
+    fields =>  {
+      MANUFACTURER => {},
+      TYPE => {},
+      SERIALNUMBER => {},
+      SPEED => {},
+      CORES => {},
+      L2CACHESIZE => {}, 
+      CPUARCH => {},
+      DATA_WIDTH => {},
+      CURRENT_ADDRESS_WIDTH => {},
+      LOGICAL_CPUS => {},
+      VOLTAGE => {},
+      CURRENT_SPEED => {},
+      SOCKET => {}
+    }
+  },
+
+  sim => {
+    mask => 524288,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'SERIALNUMBER',
+    writeDiff => 1,
+    cache => 0,
+    fields =>  {
+      OPERATOR => {},
+      OPNAME => {},
+      COUNTRY => {},
+      SERIALNUMBER => {},
+      DEVICEID => {}
+    }
+  },
+
+  batteries =>  {
+    mask => 1048576,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'NAME',
+    writeDiff => 1,
+    cache => 0,
+    fields => {
+      LOCATION => {},
+      MANUFACTURER => {},
+      MANUFACTUREDATE => {},
+      SERIALNUMBER => {},
+      NAME => {},
+      CHEMISTRY => {},
+      DESIGNCAPACITY => {},
+      DESIGNVOLTAGE => {},
+      SBDSVERSION => {},
+      MAXERROR => {},
+      OEMSPECIFIC => {}
+    }
+  },
+
+  usbdevices => {
+    mask => 2097152,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'DESCRIPTION',
+    writeDiff => 1,
+    cache => 0,
+    fields => {
+      DESCRIPTION => {},
+      INTERFACE => {},
+      MANUFACTURER => {},
+      SERIAL => {},
+      TYPE => {} 
+    }
+  },
+
+  javainfo => {
     mask => 0,
     multi => 0,
     auto => 1,
@@ -482,496 +584,517 @@ javainfo => {
   },
 
   snmp => {
-   mask => 1,
-   multi => 0,
-   auto => 0,
-   delOnReplace => 1,
-   sortBy => 'IPADDRESS',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       ID => { noXml => 1 },
-       IPADDR => {},
-       MACADDR => {},
-       SNMPDEVICEID => {},
-       NAME => {},
-       DESCRIPTION => {},
-       CONTACT => {},
-       LOCATION => {},
-       UPTIME => {},
-       DOMAIN => {},
-       TYPE => {},
-       LASTDATE => {},
-       CHECKSUM => {},
-   }
+    mask => 1,
+    multi => 0,
+    auto => 0,
+    delOnReplace => 1,
+    sortBy => 'IPADDRESS',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      ID => { noXml => 1 },
+      IPADDR => {},
+      MACADDR => {},
+      SNMPDEVICEID => {},
+      NAME => {},
+      DESCRIPTION => {},
+      CONTACT => {},
+      LOCATION => {},
+      UPTIME => {},
+      DOMAIN => {},
+      TYPE => {},
+      LASTDATE => {},
+      CHECKSUM => {}
+    }
   },
 
   snmp_printers => {
-   mask => 2,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => 'NAME',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-       SERIALNUMBER => {},
-       COUNTER => {},
-       STATUS => {},
-       ERRORSTATE => {},
-   }
+    mask => 2,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'NAME',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {},
+      SERIALNUMBER => {},
+      COUNTER => {},
+      STATUS => {},
+      ERRORSTATE => {}
+    }
   },
 
   snmp_switchs => {
-   mask => 4,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       MANUFACTURER => {},
-       REFERENCE => {},
-       TYPE => {},
-       SOFTVERSION => {},
-       FIRMVERSION => {},
-       SERIALNUMBER => {},
-       REVISION => {},
-       DESCRIPTION => {},
-   }
+    mask => 4,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      MANUFACTURER => {},
+      REFERENCE => {},
+      TYPE => {},
+      SOFTVERSION => {},
+      FIRMVERSION => {},
+      SERIALNUMBER => {},
+      REVISION => {},
+      DESCRIPTION => {}
+    }
   },
 
   snmp_firewalls => {
-   mask => 8,
-   multi => 0,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       SERIALNUMBER => {},
-       SYSTEM => {},
-   }
+    mask => 8,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      SERIALNUMBER => {},
+      SYSTEM => {}
+    }
   },
 
   snmp_blades => {
-   mask => 16,
-   multi => 0,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
+    mask => 16,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
        SERIALNUMBER => {},
-       SYSTEM => {},
-   }
+       SYSTEM => {}
+    }
   },
 
   snmp_loadbalancers => {
-   mask => 32,
-   multi => 0,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
+    mask => 32,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
        SERIALNUMBER => {},
        SYSTEM => {},
-   }
+       TYPE => {},
+       MANUFACTURER => {}
+    }
   },
 
   snmp_trays => {
-   mask => 64,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => 'NAME',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-       DESCRIPTION => {},
-       LEVEL => {},
-       MAXCAPACITY => {},
-   }
+    mask => 64,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'NAME',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {},
+      DESCRIPTION => {},
+      LEVEL => {},
+      MAXCAPACITY => {}
+    }
   },
 
   snmp_cartridges => {
-   mask => 128,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => 'DESCRIPTION',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       TYPE => {},
-       LEVEL => {},
-       MAXCAPACITY => {},
-       COLOR => {},
-   }
+    mask => 128,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'DESCRIPTION',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      TYPE => {},
+      LEVEL => {},
+      MAXCAPACITY => {},
+      COLOR => {}
+    }
   },
 
   snmp_networks => {
-   mask => 256,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       MACADDR => {},
-       DEVICEMACADDR => {},
-       SLOT => {},
-       STATUS => {},
-       SPEED => {},
-       TYPE => {},
-       DEVICEADDRESS => {},
-       DEVICENAME => {},
-       DEVICEPORT => {},
-       DEVICETYPE => {},
-       TYPEMIB => {},
-       IPADDR => {},
-       IPMASK => {},
-       IPGATEWAY => {},
-       IPSUBNET => {},
-       IPDHCP => {},
-       DRIVER => {},
-       VIRTUALDEV => {},
-   }
+    mask => 256,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      MACADDR => {},
+      DEVICEMACADDR => {},
+      SLOT => {},
+      STATUS => {},
+      SPEED => {},
+      TYPE => {},
+      DEVICEADDRESS => {},
+      DEVICENAME => {},
+      DEVICEPORT => {},
+      DEVICETYPE => {},
+      TYPEMIB => {},
+      IPADDR => {},
+      IPMASK => {},
+      IPGATEWAY => {},
+      IPSUBNET => {},
+      IPDHCP => {},
+      DRIVER => {},
+      VIRTUALDEV => {}
+    }
   },
 
   snmp_storages => {
-   mask => 512,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       MANUFACTURER => {},
-       NAME => {},
-       MODEL => {},
-       DISKSIZE => {},
-       TYPE => {},
-       SERIALNUMBER => {},
-       FIRMWARE => {},
-   }
+    mask => 512,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      MANUFACTURER => {},
+      NAME => {},
+      MODEL => {},
+      DISKSIZE => {},
+      TYPE => {},
+      SERIALNUMBER => {},
+      FIRMWARE => {}
+    }
   },
 
-
   snmp_drives => {
-   mask => 1024,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       LETTER => {},
-       TYPE => {},
-       FILESYSTEM => {},
-       TOTAL => {},
-       FREE => {},
-       NUMFILES => {},
-       VOLUMN => {},
-       LABEL => {},
-       SERIAL => {},
-   }
+    mask => 1024,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      LETTER => {},
+      TYPE => {},
+      FILESYSTEM => {},
+      TOTAL => {},
+      FREE => {},
+      NUMFILES => {},
+      VOLUMN => {},
+      LABEL => {},
+      SERIAL => {}
+    }
   },
 
   snmp_powersupplies => {
-   mask => 2048,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       MANUFACTURER => {},
-       REFERENCE => {},
-       TYPE => {},
-       SERIALNUMBER => {},
-       DESCRIPTION => {},
-       REVISION => {},
-   }
+    mask => 2048,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      MANUFACTURER => {},
+      REFERENCE => {},
+      TYPE => {},
+      SERIALNUMBER => {},
+      DESCRIPTION => {},
+      REVISION => {}
+    }
   },
 
   snmp_fans => {
-   mask => 4096,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       REFERENCE => {},
-       REVISION => {},
-       SERIALNUMBER => {},
-       MANUFACTURER => {},
-       TYPE => {},
-   }
+    mask => 4096,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      REFERENCE => {},
+      REVISION => {},
+      SERIALNUMBER => {},
+      MANUFACTURER => {},
+      TYPE => {}
+    }
   },
 
-
   snmp_cards => {
-   mask => 8192,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       REFERENCE => {},
-       FIRMWARE => {},
-       SOFTWARE => {},
-       REVISION => {},
-       SERIALNUMBER => {},
-       MANUFACTURER => {},
-       TYPE => {},
-   }
+    mask => 8192,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      REFERENCE => {},
+      FIRMWARE => {},
+      SOFTWARE => {},
+      REVISION => {},
+      SERIALNUMBER => {},
+      MANUFACTURER => {},
+      TYPE => {}
+    }
   },
 
   snmp_switchinfos => {
-   mask => 16384,
-   multi => 0,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => 'TYPE',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       TYPE => {},
-   }
+    mask => 16384,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => 'TYPE',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+     TYPE => {}
+    }
   },
 
   snmp_computers => {
-   mask => 32768,
-   multi => 0,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       SYSTEM => {},
-   }
+    mask => 32768,
+    multi => 0,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      SYSTEM => {}
+    }
   },
 
   snmp_softwares => {
-   mask => 65536,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-       INSTALLDATE => {},
-       COMMENTS => {},
-       VERSION => {},
-   }
+    mask => 65536,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {},
+      INSTALLDATE => {},
+      COMMENTS => {},
+      VERSION => {}
+    }
   },
 
   snmp_memories => {
-   mask => 131072,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       CAPACITY => {},
-   }
+    mask => 131072,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+     CAPACITY => {}
+    }
   },
 
   snmp_cpus => {
-   mask => 262144,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       SPEED => {},
-       TYPE => {},
-       MANUFACTURER => {},
-   }
+    mask => 262144,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      SPEED => {},
+      TYPE => {},
+      MANUFACTURER => {}
+    }
   },
 
   snmp_inputs => {
-   mask => 524288,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       DESCRIPTION => {},
-       TYPE => {},
-   }
+    mask => 524288,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      DESCRIPTION => {},
+      TYPE => {}
+    }
   },
 
   snmp_ports => {
-   mask => 1048576,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-       TYPE => {},
-   }
+    mask => 1048576,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {},
+      TYPE => {}
+    }
   },
 
   snmp_sounds => {
-   mask => 2097152,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-   }
+    mask => 2097152,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {}
+    }
   },
 
   snmp_videos => {
-   mask => 4194304,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-   }
+    mask => 4194304,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {}
+    }
   },
 
   snmp_modems => {
-   mask => 8388608,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-   }
+    mask => 8388608,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {}
+    }
   },
 
   snmp_localprinters => {
-   mask => 16777216,
-   multi => 1,
-   auto => 1,
-   delOnReplace => 1,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       NAME => {},
-   }
+    mask => 16777216,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      NAME => {}
+    }
+  },
+
+  snmp_virtualmachines => {
+    mask => 33554432,
+    multi => 1,
+    auto => 1,
+    delOnReplace => 1,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      CONFIG_FILE => {},
+      CPU => {},
+      MEMORY => {},
+      NAME => {},
+      OS => {},
+      POWER => {},
+      UUID => {} 
+    }
   },
 
   snmp_accountinfo =>  {
-   mask => 0,
-   multi => 1,
-   auto => 0,
-   delOnReplace => 1,
-   sortBy => 'TAG',
-   writeDiff => 0,
-   cache => 0,
-   fields => {
-       TAG => {}
-   }
+    mask => 0,
+    multi => 1,
+    auto => 0,
+    delOnReplace => 1,
+    sortBy => 'TAG',
+    writeDiff => 0,
+    cache => 0,
+    fields => {
+      TAG => {}
+    }
   },
 
   snmp_laststate => {
-   mask => 0,
-   multi => 0,
-   auto => 0,
-   delOnReplace => 0,
-   sortBy => '',
-   writeDiff => 1,
-   cache => 0,
-   capacities => 'snmp',
-   fields =>  {
-       COMMON => {},
-       PRINTERS => {},
-       TRAYS => {},
-       CARTRIDGES => {},
-       NETWORKS => {},
-       SWITCHS => {},
-       BLADES => {},
-       STORAGES => {},
-       DRIVES => {},
-       POWERSUPPLIES => {},
-       FANS => {},
-       LOADBALANCERS => {},
-       CARDS => {},
-       FIREWALLS => {},
-       SWITCHINFOS => {},
-       COMPUTERS => {},
-       SOFTWARES => {},
-       MEMORIES => {},
-       CPUS => {},
-       INPUTS => {},
-       PORTS => {},
-       SOUNDS => {},
-       VIDEOS => {},
-       MODEMS => {},
-       LOCALPRINTERS => {},
-   }
+    mask => 0,
+    multi => 0,
+    auto => 0,
+    delOnReplace => 0,
+    sortBy => '',
+    writeDiff => 1,
+    cache => 0,
+    capacities => 'snmp',
+    fields =>  {
+      COMMON => {},
+      PRINTERS => {},
+      TRAYS => {},
+      CARTRIDGES => {},
+      NETWORKS => {},
+      SWITCHS => {},
+      BLADES => {},
+      STORAGES => {},
+      DRIVES => {},
+      POWERSUPPLIES => {},
+      FANS => {},
+      LOADBALANCERS => {},
+      CARDS => {},
+      FIREWALLS => {},
+      SWITCHINFOS => {},
+      COMPUTERS => {},
+      SOFTWARES => {},
+      MEMORIES => {},
+      CPUS => {},
+      INPUTS => {},
+      PORTS => {},
+      SOUNDS => {},
+      VIDEOS => {},
+      MODEMS => {},
+      LOCALPRINTERS => {},
+      VIRTUALMACHINES => {}
+    }
   },
 
 );
