@@ -1,11 +1,23 @@
 ###############################################################################
-## OCSINVENTORY-NG 
-## Copyleft Pascal DANEK 2005
-## Web : http://www.ocsinventory-ng.org
+## Copyright 2005-2016 OCSInventory-NG/OCSInventory-Server contributors.
+## See the Contributors file for more details about them.
+## 
+## This file is part of OCSInventory-NG/OCSInventory-ocsreports.
 ##
-## This code is open source and may be copied and modified as long as the source
-## code is always made freely available.
-## Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
+## OCSInventory-NG/OCSInventory-Server is free software: you can redistribute
+## it and/or modify it under the terms of the GNU General Public License as
+## published by the Free Software Foundation, either version 2 of the License,
+## or (at your option) any later version.
+##
+## OCSInventory-NG/OCSInventory-Server is distributed in the hope that it
+## will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+## of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with OCSInventory-NG/OCSInventory-ocsreports. if not, write to the
+## Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+## MA 02110-1301, USA.
 ################################################################################
 package Apache::Ocsinventory::Server::System;
 
@@ -77,7 +89,7 @@ sub _get_sys_options{
 
   return 0 if $ENV{OCS_OPT_OPTIONS_NOT_OVERLOADED};
 
-  # Wich options enabled ?
+  # Which options enabled ?
   #############
   # We read the table config looking for the ivalues of these options
   my $dbh = $Apache::Ocsinventory::CURRENT_CONTEXT{'DBI_HANDLE'};
@@ -97,7 +109,7 @@ sub _get_sys_options{
   0;
 }
 
-# Try other compress algorythm
+# Try other compress algorithm
 sub _inflate{
   my @inflate_subs = (
     # gzip file content
@@ -197,7 +209,7 @@ sub _lock{
    my $device = shift;
    my $dbh = $Apache::Ocsinventory::CURRENT_CONTEXT{'DBI_HANDLE'} || shift;
   
-  if($dbh->do('INSERT INTO locks(HARDWARE_ID, ID, SINCE) VALUES(?,?,NULL)', {} , $device, $$ )){
+  if($dbh->do('INSERT INTO locks(HARDWARE_ID, ID, SINCE) VALUES(?,?,NOW())', {} , $device, $$ )){
     $Apache::Ocsinventory::CURRENT_CONTEXT{'LOCK_FL'} = 1 
       if $device eq ${Apache::Ocsinventory::CURRENT_CONTEXT{'DATABASE_ID'}};
     return(0);
@@ -243,7 +255,7 @@ sub _log{
   
   if(!$LOG){
     open LOG, '>>'.$ENV{'OCS_OPT_LOGPATH'}.'/activity.log' or die "Failed to open log file : $! ($ENV{'OCS_OPT_LOGPATH'})\n";
-    # We don't want buffer, so we allways flush the handles
+    # We don't want buffer, so we always flush the handles
     select(LOG);
     $|=1;
     $LOG = \*LOG;
